aboutsummaryrefslogtreecommitdiff
path: root/config/p10k-pure.zsh
diff options
context:
space:
mode:
Diffstat (limited to 'config/p10k-pure.zsh')
-rw-r--r--config/p10k-pure.zsh112
1 files changed, 69 insertions, 43 deletions
diff --git a/config/p10k-pure.zsh b/config/p10k-pure.zsh
index 271504e2..20f5b3f2 100644
--- a/config/p10k-pure.zsh
+++ b/config/p10k-pure.zsh
@@ -6,25 +6,29 @@
# - `@c4d3ec2c` instead of something like `v1.4.0~11` when in detached HEAD state.
# - No automatic `git fetch` (the same as in Pure with `PURE_GIT_PULL=0`).
#
-# The replication of Pure prompt achieved with this config is almost exact. Apart from the
-# differences listed above, prompt is identical to Pure. This includes even the bad parts.
-# For example, just like in Pure, prompt will provide no indication of Git status being stale.
-# This is likely to make user experience worse than with any other Powerlevel10k config. If
-# you like the general style of Pure but not particularly attached to all its quirks, type
-# `p9k_configure` while having Powerlevel10k theme active and pick lean style.
-
-# Temporarily disable aliases.
-if [[ -o 'aliases' ]]; then
- 'builtin' 'unsetopt' 'aliases'
- local p10k_pure_restore_aliases=1
-else
- local p10k_pure_restore_aliases=0
-fi
+# Apart from the differences listed above, the replication of Pure prompt is exact. This includes
+# even the questionable parts. For example, just like in Pure, there is no indication of Git status
+# being stale; prompt symbol is the same in command, visual and overwrite vi modes; when prompt
+# doesn't fit on one line, it wraps around with no attempt to shorten it.
+#
+# If you like the general style of Pure but not particularly attached to all its quirks, type
+# `p10k configure` while having Powerlevel10k theme active and pick "Lean" style.
+
+# Temporarily change options.
+'builtin' 'local' '-a' 'p10k_config_opts'
+[[ ! -o 'aliases' ]] || p10k_config_opts+=('aliases')
+[[ ! -o 'sh_glob' ]] || p10k_config_opts+=('sh_glob')
+[[ ! -o 'no_brace_expand' ]] || p10k_config_opts+=('no_brace_expand')
+'builtin' 'setopt' 'no_aliases' 'no_sh_glob' 'brace_expand'
() {
emulate -L zsh
setopt no_unset
+ # Unset all configuration options.
+ unset -m 'POWERLEVEL9K_*'
+
+ # Left prompt segments.
typeset -g POWERLEVEL9K_LEFT_PROMPT_ELEMENTS=(
dir # current directory
vcs # git status
@@ -34,16 +38,19 @@ fi
virtualenv # python virtual environment
prompt_char # prompt symbol
)
+
+ # Right prompt segments.
typeset -g POWERLEVEL9K_RIGHT_PROMPT_ELEMENTS=()
- # Basic style options that define the overall look of your prompt.
+ # Basic style options that define the overall prompt look.
typeset -g POWERLEVEL9K_BACKGROUND= # transparent background
typeset -g POWERLEVEL9K_{LEFT,RIGHT}_{LEFT,RIGHT}_WHITESPACE= # no surrounding whitespace
typeset -g POWERLEVEL9K_{LEFT,RIGHT}_SUBSEGMENT_SEPARATOR=' ' # separate segments with a space
typeset -g POWERLEVEL9K_{LEFT,RIGHT}_SEGMENT_SEPARATOR= # no end-of-line symbol
- typeset -g POWERLEVEL9K_VISUAL_IDENTIFIER_EXPANSION= # disable segment icons
+ typeset -g POWERLEVEL9K_VISUAL_IDENTIFIER_EXPANSION= # no segment icons
- # Add an empty line before each prompt.
+ # Add an empty line before each prompt except the first. This doesn't emulate the bug
+ # in Pure that makes prompt drift down whenever you use the ALT-C binding from fzf or similar.
typeset -g POWERLEVEL9K_PROMPT_ADD_NEWLINE=true
# Magenta prompt symbol if the last command succeeded.
@@ -57,38 +64,25 @@ fi
# Prompt symbol in visual vi mode is the same as in command mode. This is unlikely
# to be desired by anyone but that's how Pure does it.
typeset -g POWERLEVEL9K_PROMPT_CHAR_{OK,ERROR}_VIVIS_CONTENT_EXPANSION='❮'
+ # Prompt symbol in overwrite vi mode is the same as in command mode. This is unlikely
+ # to be desired by anyone but that's how Pure does it.
+ typeset -g POWERLEVEL9K_PROMPT_CHAR_OVERWRITE_STATE=false
# Grey Python Virtual Environment.
typeset -g POWERLEVEL9K_VIRTUALENV_FOREGROUND=242
+ # Don't show Python version.
+ typeset -g POWERLEVEL9K_VIRTUALENV_SHOW_PYTHON_VERSION=false
+ typeset -g POWERLEVEL9K_VIRTUALENV_{LEFT,RIGHT}_DELIMITER=
# Blue current directory.
typeset -g POWERLEVEL9K_DIR_FOREGROUND=blue
- # Make Git prompt grey in all states. Also make stale prompts appear indistinguishable from
- # fresh ones. This is unlikely to be desired by anyone but that's how Pure does it.
- typeset -g POWERLEVEL9K_VCS_FOREGROUND=242
-
- # Disable async loading indicator to make directories that aren't Git repositories
- # indistinguishable from large Git repositories without known state. This is unlikely
- # to be desired by anyone but that's how Pure does it.
- local vcs='${${P9K_CONTENT:#loading}:+'
- # 'feature' or '@72f5c8a' if not on a branch.
- vcs+='${${VCS_STATUS_LOCAL_BRANCH//\%/%%}:-%f@${VCS_STATUS_COMMIT[1,8]}}'
- # '*' if dirty.
- vcs+='${${${:-$VCS_STATUS_HAS_STAGED$VCS_STATUS_HAS_UNSTAGED$VCS_STATUS_HAS_UNTRACKED}:#000}:+*}'
- # ⇣ if behind the remote.
- vcs+='${${VCS_STATUS_COMMITS_BEHIND:#0}:+ %6F⇣}'
- # ⇡ if ahead of the remote; no leading space if also behind the remote: ⇣⇡.
- vcs+='${${VCS_STATUS_COMMITS_AHEAD:#0}:+${${(M)VCS_STATUS_COMMITS_BEHIND:#0}:+ }%6F⇡}}'
- typeset -g POWERLEVEL9K_VCS_CONTENT_EXPANSION=$vcs
-
# Context format when root: user@host. The first part white, the rest grey.
- typeset -g POWERLEVEL9K_CONTEXT_ROOT_CONTENT_EXPANSION='%7F%n%f%242F@%m%f'
- # Context format when connected over SSH: user@host. The whole thing grey.
- typeset -g POWERLEVEL9K_CONTEXT_{REMOTE,REMOTE_SUDO}_CONTENT_EXPANSION='%242F%n@%m%f'
- # Don't show context when not rood and not connected over SSH.
- typeset -g POWERLEVEL9K_CONTEXT_CONTENT_EXPANSION=
- typeset -g POWERLEVEL9K_ALWAYS_SHOW_CONTEXT=true
+ typeset -g POWERLEVEL9K_CONTEXT_ROOT_TEMPLATE='%7F%n%f%242F@%m%f'
+ # Context format when not root: user@host. The whole thing grey.
+ typeset -g POWERLEVEL9K_CONTEXT_TEMPLATE='%242F%n@%m%f'
+ # Don't show context unless root or in SSH.
+ typeset -g POWERLEVEL9K_CONTEXT_{DEFAULT,SUDO}_CONTENT_EXPANSION=
# Show previous command duration only if it's >= 5s.
typeset -g POWERLEVEL9K_COMMAND_EXECUTION_TIME_THRESHOLD=5
@@ -98,7 +92,39 @@ fi
typeset -g POWERLEVEL9K_COMMAND_EXECUTION_TIME_FORMAT='d h m s'
# Yellow previous command duration.
typeset -g POWERLEVEL9K_COMMAND_EXECUTION_TIME_FOREGROUND=yellow
+
+ # Grey Git prompt. This makes stale prompts indistinguishable from up-to-date ones.
+ typeset -g POWERLEVEL9K_VCS_FOREGROUND=242
+
+ # Disable async loading indicator to make directories that aren't Git repositories
+ # indistinguishable from large Git repositories without known state.
+ typeset -g POWERLEVEL9K_VCS_LOADING_TEXT=
+
+ # Don't wait for Git status even for a millisecond, so that prompt always updates
+ # asynchronously when Git state changes.
+ typeset -g POWERLEVEL9K_VCS_MAX_SYNC_LATENCY_SECONDS=0
+
+ # Cyan ahead/behind arrows.
+ typeset -g POWERLEVEL9K_VCS_{INCOMING,OUTGOING}_CHANGESFORMAT_FOREGROUND=cyan
+ # Don't show remote branch, current tag or stashes.
+ typeset -g POWERLEVEL9K_VCS_GIT_HOOKS=(vcs-detect-changes git-untracked git-aheadbehind)
+ # Don't show the branh icon.
+ typeset -g POWERLEVEL9K_VCS_BRANCH_ICON=
+ # When in detached HEAD state, show @commit where branch normally goes.
+ typeset -g POWERLEVEL9K_VCS_COMMIT_ICON='@'
+ # Don't show staged, unstaged, untracked indicators.
+ typeset -g POWERLEVEL9K_VCS_{STAGED,UNSTAGED,UNTRACKED}_ICON=$'\b'
+ # Show '*' when there are staged, unstaged or untracked files.
+ typeset -g POWERLEVEL9K_VCS_DIRTY_ICON='*'
+ # Show '⇣' if local branch is behind remote.
+ typeset -g POWERLEVEL9K_VCS_INCOMING_CHANGES_ICON='⇣'
+ # Show '⇡' if local branch is ahead of remote.
+ typeset -g POWERLEVEL9K_VCS_OUTGOING_CHANGES_ICON='⇡'
+ # Don't show the number of commits next to the ahead/behind arrows.
+ typeset -g POWERLEVEL9K_VCS_{COMMITS_AHEAD,COMMITS_BEHIND}_MAX_NUM=1
+ # Remove space between '⇣' and '⇡', and get rid of $' \b'.
+ typeset -g POWERLEVEL9K_VCS_CONTENT_EXPANSION=$'${${P9K_CONTENT/⇣* ⇡/⇣⇡}// \b}'
}
-(( ! p10k_pure_restore_aliases )) || setopt aliases
-'builtin' 'unset' 'p10k_pure_restore_aliases'
+(( ${#p10k_config_opts} )) && setopt ${p10k_config_opts[@]}
+'builtin' 'unset' 'p10k_config_opts'